"""
TILMedia Exception Classes
"""


class TILMediaError(Exception):
    """
    TILMedia Error without further specification.
    """

    def __init__(self, message, index=None):
        Exception.__init__(self, message)
        self.message = message
        self.index = index

    def __str__(self):
        return self.message

    def with_traceback(self, *args, **kwargs):
        # wrapper required to build docs with python 3.9 and sphinx on linux...
        Exception.with_traceback(*args, **kwargs)


class TILMediaErrorInvalidMedium(TILMediaError):
    """
    An invalid medium name was given. Either the name is invalid in general, the medium could not
    be found, or the license does not allow it. Consult the message provided.
    """


class TILMediaErrorInvalidLicense(TILMediaError):
    """
    The TILMedia license is not available.
    """


class TILMediaErrorInvalidParameter(TILMediaError):
    """
    Invalid parameters were given by the user.
    """


class TILMediaErrorIncompatibleVectorLength(TILMediaError):
    """
    The lengths of the input data vectors are incompatible. E.g. different lengths for pressure
    and enthalpy arrays.
    """
